package com.yanzhu.manage.mapper;

import java.util.List;
import com.yanzhu.manage.domain.ProProjectInfoSetting;

/**
 * 项目设置Mapper接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface ProProjectInfoSettingMapper 
{
    /**
     * 查询项目设置
     * 
     * @param id 项目设置主键
     * @return 项目设置
     */
    public ProProjectInfoSetting selectProProjectInfoSettingById(Long id);

    /**
     * 查询项目设置列表
     * 
     * @param proProjectInfoSetting 项目设置
     * @return 项目设置集合
     */
    public List<ProProjectInfoSetting> selectProProjectInfoSettingList(ProProjectInfoSetting proProjectInfoSetting);

    /**
     * 新增项目设置
     * 
     * @param proProjectInfoSetting 项目设置
     * @return 结果
     */
    public int insertProProjectInfoSetting(ProProjectInfoSetting proProjectInfoSetting);

    /**
     * 修改项目设置
     * 
     * @param proProjectInfoSetting 项目设置
     * @return 结果
     */
    public int updateProProjectInfoSetting(ProProjectInfoSetting proProjectInfoSetting);

    /**
     * 删除项目设置
     * 
     * @param id 项目设置主键
     * @return 结果
     */
    public int deleteProProjectInfoSettingById(Long id);

    /**
     * 批量删除项目设置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProProjectInfoSettingByIds(Long[] ids);
}
